==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Effect/stereo/translations/stereo_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="31"/>
        <source>Extra Stereo Plugin</source>
        <translation>תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>About Extra Stereo Plugin</source>
        <translation>אודות תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>תוסף סטריאו נוסף של Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="54"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>מבוסס על תוסף סטריאו נוסף עבור Xmms מאתJohan Levin</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>הגדרות תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>חוזק אפקט:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Effect/stereo/translations/stereo_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="31"/>
        <source>Extra Stereo Plugin</source>
        <translation>תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>About Extra Stereo Plugin</source>
        <translation>אודות תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>תוסף סטריאו נוסף של Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="54"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>מבוסס על תוסף סטריאו נוסף עבור Xmms מאתJohan Levin</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>הגדרות תוסף סטריאו נוסף</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>חוזק אפקט:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
